var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};
import React, { forwardRef, useRef, useImperativeHandle, useCallback, useMemo } from "react";
import { _ as _default } from "./react-email-editor.js";
import { toPng } from "html-to-image";
const customCSS = [
  "::-webkit-scrollbar{width:8px;height:8px;}::-webkit-scrollbar-thumb{border-radius:5px;background:#bfbfbf;}::-webkit-scrollbar-track{background:transparent;}::-webkit-scrollbar-thumb:hover{border-radius:5px;background:#4a9cee;}",
  "https://cdn.jsdelivr.net/npm/freemarker-web-editor@1.0.0/css/fm-editor.css",
  "https://cdn.jsdelivr.net/npm/freemarker-web-editor@1.0.0/css/fm-codemirror.css",
  "https://cdn.jsdelivr.net/npm/freemarker-web-editor@1.0.0/css/fm-hint.css",
  "https://cdn.jsdelivr.net/npm/freemarker-web-editor@1.0.0/css/fm-syntax.css"
];
const suffix = "https://cdn.jsdelivr.net/npm/quick-email-editor-v2@0.4.9/uploadJS/";
const customJS = [
  `${suffix}productProperties.js`,
  `${suffix}productTool.js`,
  `${suffix}couponProperties.js`,
  `${suffix}couponTool.js`,
  `${suffix}htmlProperties.js`,
  `${suffix}htmlTool.js`
];
const codeMirror = [
  "https://cdn.jsdelivr.net/npm/freemarker-web-editor@1.0.0/js/dojo-1.9.1-bin/dojo.js",
  "https://cdn.jsdelivr.net/npm/freemarker-web-editor@1.0.0/js/codemirror-3.0-bin/codemirror-compressed.js",
  "https://cdn.jsdelivr.net/npm/freemarker-web-editor@1.0.0/js/fm/fm-editor.min.js"
];
const showDiscountPlatform = ["shopify", "shoplazza", "shopline"];
const generateJs = (customFonts, platform) => {
  const tempCustomJS = JSON.parse(JSON.stringify(customJS));
  if ((customFonts == null ? void 0 : customFonts.length) > 3) {
    tempCustomJS.splice(2, 2);
  } else if (showDiscountPlatform.includes(platform)) {
    tempCustomJS.splice(4, 2);
  } else {
    tempCustomJS.splice(2, 4);
  }
  return [...tempCustomJS, ...codeMirror];
};
const html2Image = (html) => __async(void 0, null, function* () {
  console.time("html2Image");
  const container = document.createElement("div");
  container.innerHTML = html;
  container.style.position = "absolute";
  container.style.left = "0";
  [...container.getElementsByTagName("img")].forEach((img) => {
    img.setAttribute("src", img.src + "?" + new Date().getTime());
  });
  document.body.appendChild(container);
  const blob = yield toPng(container).then((dataUrl) => {
    console.timeEnd("html2Image");
    return dataUrl;
  });
  document.body.removeChild(container);
  return blob;
});
Date.prototype.format = function(format) {
  var o = {
    "M+": this.getMonth() + 1,
    "d+": this.getDate(),
    "h+": this.getHours(),
    "m+": this.getMinutes(),
    "s+": this.getSeconds(),
    "q+": Math.floor((this.getMonth() + 3) / 3),
    S: this.getMilliseconds()
  };
  if (/(y+)/.test(format))
    format = format.replace(RegExp.$1, (this.getFullYear() + "").substr(4 - RegExp.$1.length));
  for (var k in o)
    if (new RegExp("(" + k + ")").test(format))
      format = format.replace(RegExp.$1, RegExp.$1.length === 1 ? o[k] : ("00" + o[k]).substr(("" + o[k]).length));
  return format;
};
const dateFormat = (format) => {
  let formatDate = new Date().format(format);
  if (format.startsWith("MM")) {
    const month = new Date().toString().split(" ")[1];
    formatDate = month + formatDate.slice(2);
  }
  return formatDate;
};
const getOptions = (platform) => {
  const options = [
    { label: "All order", value: "ALL" },
    { label: "Minimum order price", value: "MINIMUM" },
    { label: "Collection", value: "PRODUCT_COLLECTION" }
  ];
  if (platform === "shoplazza") {
    options.splice(1, 1);
  }
  return options;
};
const discountProperties = (quickToken, platform, storeLink, getConnectionUrl, timeZone) => {
  return {
    discountType: {
      editor: {
        data: {
          options: [
            { label: "Cart discount", value: "ORDER_DISCOUNT" },
            { label: "Free shipping", value: "FREE_SHIP" }
          ]
        }
      }
    },
    discountRange: {
      editor: {
        data: {
          options: getOptions(platform)
        }
      }
    },
    expiresDays: {
      editor: {
        data: {
          label: "Expires in",
          suffix: "days",
          timeZone,
          quickToken
        }
      }
    },
    limitUsedValue: {
      editor: {
        data: {
          label: "No. of times the discount can be used intotal"
        }
      }
    },
    minimumOrderPrice: {
      editor: {
        data: {
          label: "Minimum order price",
          desc: "The amount will be set in your store's currency"
        }
      }
    },
    reduceValue: {
      editor: {
        data: {
          label: "Discount value",
          desc: "The amount will be set in your store's currency"
        }
      }
    },
    reduceValuePercent: {
      editor: {
        data: {
          label: "Discount value",
          suffix: "%"
        }
      }
    },
    expireDateFormat: {
      editor: {
        data: {
          options: [
            { label: dateFormat("MM dd,yyyy"), value: "MM dd,yyyy" },
            { label: dateFormat("yyyy-MM-dd"), value: "yyyy-MM-dd" },
            { label: dateFormat("dd/MM/yyyy"), value: "dd/MM/yyyy" }
          ]
        }
      }
    },
    buttonType: {
      editor: {
        data: {
          options: [
            { label: "Primary button", value: "primary" },
            { label: "Secondary button", value: "secondary" },
            { label: "Tertiary button", value: "tertiary" }
          ]
        }
      }
    },
    reduceType: {
      editor: {
        data: {
          label: "Value type",
          options: [
            { label: "Percentage", value: "PERCENTAGE" },
            { label: "Fixed amount", value: "FIXED_AMOUNT" }
          ]
        }
      }
    },
    limitUsedType: {
      editor: {
        data: {
          label: "A customer can use the discount",
          options: [
            { label: "Unlimited times", value: "LIMIT_TOTAL" },
            { label: "Only once", value: "LIMIT_PER_CUSTOMER" }
          ]
        }
      }
    },
    buttonLink: {
      editor: {
        data: {
          label: "Button link",
          storeLink
        }
      }
    },
    autoDiscount: {
      editor: {
        data: {
          label: "Apply Shopify discount link",
          platform,
          desc: "lf enabled, we'll automatically applythe discount once the customerreaches the checkout page.",
          storeLink
        }
      }
    },
    collectionList: {
      editor: {
        data: {
          label: "Connection name",
          getConnectionUrl,
          quickToken
        }
      }
    }
  };
};
const QuickEditor = forwardRef(({ quickToken, editorConfig, height, uploadImage, updateDesign, getProductUrl, getProductByTypeUrl, systemParam, customFonts, platform, storeLink, getConnectionUrl, timeZone }, ref) => {
  const emailEditorRef = useRef(null);
  const prepareSaveDesign = (design) => {
    const errors = [];
    const checkUrlByType = {
      button: (values) => {
        const { name, values: { href } } = values.href;
        if (name === "web" && !href) {
          const div = document.createElement("div");
          div.innerHTML = values.text;
          const text = div.innerText;
          errors.push({
            id: values._meta.htmlID,
            content: `BUTTON-${text}`,
            type: !href ? "noneError" : "typeError"
          });
        }
      },
      social: (values) => {
        const { icons } = values.icons;
        icons.forEach((icon) => {
          const { name, url } = icon;
          if (!url) {
            errors.push({
              id: values._meta.htmlID,
              content: `SOCIAL-${name}`,
              type: !url ? "noneError" : "typeError"
            });
          }
        });
      },
      menu: (values) => {
        const { items } = values.menu;
        items.forEach((item) => {
          const { link: { name, values: linkValues }, text } = item;
          if (name === "web" && !linkValues.href) {
            errors.push({
              id: values._meta.htmlID,
              content: `MENU-${text}`,
              type: !linkValues.href ? "noneError" : "typeError"
            });
          }
        });
      }
    };
    design.body.rows.forEach((row) => {
      row.columns.forEach((column) => {
        column.contents.forEach((content) => {
          var _a;
          const { type, values } = content;
          (_a = checkUrlByType[type]) == null ? void 0 : _a.call(checkUrlByType, values);
        });
      });
    });
    return errors;
  };
  useImperativeHandle(ref, () => ({
    exportHtml: (func) => {
      var _a, _b;
      return (_b = (_a = emailEditorRef.current) == null ? void 0 : _a.editor) == null ? void 0 : _b.exportHtml(func);
    },
    saveDesign: (func, errorFunc) => {
      var _a, _b;
      (_b = (_a = emailEditorRef.current) == null ? void 0 : _a.editor) == null ? void 0 : _b.exportHtml((data) => __async(void 0, null, function* () {
        var _a2, _b2;
        let usefreemarker = false;
        data.html.includes("data-useFreeMarker") && (usefreemarker = true);
        (_b2 = (_a2 = emailEditorRef.current) == null ? void 0 : _a2.editor) == null ? void 0 : _b2.saveDesign((design) => {
          const errors = prepareSaveDesign(design);
          if (errors.length) {
            errorFunc(errors);
          } else {
            design.usefreemarker = usefreemarker;
            func(design);
          }
        });
      }));
    },
    exportImage: (func) => __async(void 0, null, function* () {
      var _a, _b;
      (_b = (_a = emailEditorRef.current) == null ? void 0 : _a.editor) == null ? void 0 : _b.exportHtml((data) => __async(void 0, null, function* () {
        const blob = yield html2Image(data.html);
        func(blob);
      }));
    }),
    loadDesign: (data) => {
      var _a, _b, _c;
      ((_a = emailEditorRef.current) == null ? void 0 : _a.editor) ? (_c = (_b = emailEditorRef.current) == null ? void 0 : _b.editor) == null ? void 0 : _c.loadDesign(data) : setTimeout(() => {
        var _a2, _b2;
        return (_b2 = (_a2 = emailEditorRef.current) == null ? void 0 : _a2.editor) == null ? void 0 : _b2.loadDesign(data);
      }, 0);
    },
    updateDesign: (func) => {
      var _a, _b;
      return (_b = (_a = emailEditorRef.current) == null ? void 0 : _a.editor) == null ? void 0 : _b.saveDesign(func);
    }
  }));
  const onDesignUpdate = useCallback(() => {
    var _a, _b;
    (_b = (_a = emailEditorRef.current) == null ? void 0 : _a.editor) == null ? void 0 : _b.exportHtml((data) => {
      const json = data == null ? void 0 : data.design;
      const html = (data == null ? void 0 : data.html) || "";
      const errors = prepareSaveDesign(json);
      updateDesign(json, html, errors);
    });
  }, [updateDesign]);
  const onDesignLoad = () => {
    var _a;
    (_a = emailEditorRef.current) == null ? void 0 : _a.registerCallback("image", (file, done) => __async(void 0, null, function* () {
      var _a2;
      yield uploadImage((_a2 = file.attachments) == null ? void 0 : _a2[0], done);
    }));
  };
  const registerEvent = () => {
    var _a, _b, _c, _d;
    (_b = (_a = emailEditorRef.current) == null ? void 0 : _a.editor) == null ? void 0 : _b.addEventListener("design:loaded", onDesignLoad);
    (_d = (_c = emailEditorRef.current) == null ? void 0 : _c.editor) == null ? void 0 : _d.addEventListener("design:updated", onDesignUpdate);
  };
  const onLoad = () => {
    var _a;
    if ((_a = emailEditorRef.current) == null ? void 0 : _a.editor) {
      initEditor();
    }
  };
  const onReady = () => {
    var _a;
    if ((_a = emailEditorRef.current) == null ? void 0 : _a.editor) {
      initEditor();
    }
  };
  const initEditor = () => {
    var _a, _b;
    registerEvent();
    (_b = (_a = emailEditorRef.current) == null ? void 0 : _a.editor) == null ? void 0 : _b.setLinkTypes([
      {
        name: "sms",
        enabled: false
      }
    ]);
  };
  const tools = useMemo(() => {
    return {
      "custom#product_tool": {
        data: {
          products: []
        },
        properties: {
          containerPadding: {
            value: "0px"
          },
          productLibrary: {
            editor: {
              data: {
                products: [],
                currentSelectProduct: [],
                keyword: "",
                getProductUrl,
                getProductByTypeUrl,
                quickToken,
                total: 10,
                totalPage: 1,
                currentPage: 1
              }
            }
          }
        }
      },
      "custom#my_tool": {
        data: {
          saveContent: ""
        }
      },
      "custom#discount": {
        usageLimit: 1,
        properties: discountProperties(quickToken, platform, storeLink, getConnectionUrl, timeZone)
      },
      image: {
        properties: {
          src: {
            value: {
              url: "https://quick-cep.oss-cn-shanghai.aliyuncs.com/446/ma/template/html2canvas/764158287988916224/ed294e6e-098d-463c-9618-30411c3794c9.png",
              width: 600,
              height: 200
            }
          }
        }
      }
    };
  }, [
    quickToken,
    getProductUrl,
    getProductByTypeUrl,
    platform,
    storeLink,
    getConnectionUrl,
    timeZone
  ]);
  const mergeTags = useMemo(() => {
    return {
      system_param: {
        name: "System param",
        mergeTags: systemParam
      },
      custom_variable: {
        name: "Custom variable",
        value: "[custom.xx]",
        sample: "[custom.xx]"
      }
    };
  }, [systemParam]);
  const options = useMemo(() => {
    return {
      mergeTagsConfig: {
        sort: false
      },
      fonts: {
        showDefaultFonts: true,
        customFonts
      },
      mergeTags,
      customCSS,
      customJS: generateJs(customFonts, platform),
      features: {
        smartMergeTags: false,
        textEditor: {
          emojis: true,
          spellChecker: true
        }
      }
    };
  }, []);
  const editor = useMemo(() => {
    var _a, _b;
    return /* @__PURE__ */ React.createElement(_default, {
      ref: emailEditorRef,
      minHeight: height,
      projectId: 88838,
      appearance: {
        theme: (_a = editorConfig == null ? void 0 : editorConfig.theme) != null ? _a : "light",
        panels: {
          tools: {
            dock: (_b = editorConfig == null ? void 0 : editorConfig.dock) != null ? _b : "right"
          }
        }
      },
      tools,
      options,
      onLoad,
      onReady
    });
  }, [height]);
  return editor;
});
export { QuickEditor };
//# sourceMappingURL=index.js.map
